package
Version:
v0.0.0-...-bdd764d
Opens a new window with list of versions in this module.
Published: Jan 13, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ProcessInfo struct {
PID int `xml:"PID"`
Path string `xml:"Path"`
Name string `xml:"Name"`
User string `xml:"User"`
SID string `xml:"SID"`
Arguments string `xml:"Arguments"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.